jactorch.functional.shape
=========================

.. automodule:: jactorch.functional.shape

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      add_dim
      add_dim_as_except
      broadcast
      broadcast_as_except
      concat_shape
      flatten
      flatten2
      force_view
      move_dim
      repeat
      repeat_times
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: add_dim

.. autofunction:: add_dim_as_except

.. autofunction:: broadcast

.. autofunction:: broadcast_as_except

.. autofunction:: concat_shape

.. autofunction:: flatten

.. autofunction:: flatten2

.. autofunction:: force_view

.. autofunction:: move_dim

.. autofunction:: repeat

.. autofunction:: repeat_times


